import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [{
      path: 'dashboard',
      name: 'Dashboard',
      component: () => import('@/views/dashboard/index'),
      meta: { title: 'Dashboard', icon: 'dashboard' }
    }]
  },

  {
    path: '/questionList',
    component: Layout,
    name: '题库管理',
    meta: { title: '题库管理', icon: 'form' },
    children: [
      {
        path: 'questionList',
        name: '题库列表',
        component: () => import('@/views/questionList/index'),
        meta: { title: '题库列表', icon: 'form' }
      },
      {
        path: 'questionList/edit',
        name: '编辑题目',
        component: () => import('@/views/questionList/edit'),
        // meta: { title: '编辑题目', icon: 'form' }
      }]
  },

  {
    path: '/characterLibManage',
    component: Layout,
    name: '特征库管理',
    meta: { title: '特征管理', icon: 'form' },
    children: [
      {
        path: 'characterLibManage',
        name: '特征库列表',
        component: () => import('@/views/characterLibManage/index'),
        meta: { title: '特征库列表', icon: 'form' }
      },
      {
        path: 'characterLibManage/add',
        name: '新增特征库',
        component: () => import('@/views/characterLibManage/add'),
        // meta: { title: '新增特征库', icon: 'form' }
      },
      {
        path: 'characterLibManage/edit',
        name: '编辑特征库',
        component: () => import('@/views/characterLibManage/edit'),
        // meta: { title: '编辑特征库', icon: 'form' }
      }
    ]
  },

  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },

  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },

    

  {
    path: 'external-link',
    component: Layout,
    children: [
      {
        path: 'https://panjiachen.github.io/vue-element-admin-site/#/',
        meta: { title: 'External Link', icon: 'link' }
      }
    ]
  },

  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
